pub struct UnwindOperator { /* private fields */ }Expand description
Iterates a list of scalar Values, emitting one row per element.
Each row has a single column named after alias.
Empty lists produce zero rows.
Implementations