Module engine

Module engine 

Query execution engine.

Converts a bound Cypher AST into an operator tree and executes it, returning a materialized QueryResult.

Structs

Engine
The execution engine holds references to the storage layer.